"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios = require("axios");
const inquirer = require("inquirer");
const core_1 = require("@oclif/core");
class ArticlesRevalidate extends core_1.Command {
    async run() {
        const { flags } = await this.parse(ArticlesRevalidate);
        if (flags.all && flags.single)
            return this.error('❌ You can not use two flags together, please use --all or --single');
        if (Object.keys(flags).length === 0) {
            const answer = await inquirer.prompt([{
                    name: 'flag',
                    message: 'Please select a flag: ',
                    type: 'list',
                    choices: [{ name: 'all' }, { name: 'single' }],
                }]);
            flags[answer.flag] = true;
        }
        if (flags.all) {
            const token = await core_1.CliUx.ux.prompt('To revalidate articles, please enter the password: ');
            try {
                core_1.CliUx.ux.action.start('revalidating...');
                const { data: { revalidated } } = await axios.get('http://heelog.dev/api/revalidate', {
                    data: {
                        type: 'all',
                        token: token,
                    },
                });
                if (revalidated) {
                    core_1.CliUx.ux.action.stop('✅ done');
                }
                else {
                    core_1.CliUx.ux.action.stop('❌ failed');
                }
            }
            catch {
                this.error('❌ Please provide valid token to run revalidation');
            }
        }
        if (flags.single) {
            const res = await axios.get('http://heelog.dev/api/notionPages');
            const { pages } = res.data;
            const answer = await inquirer.prompt([{
                    name: 'article',
                    message: 'Select an article to revalidate: ',
                    type: 'list',
                    choices: [...pages],
                }]);
            const page = pages.find((p) => {
                if (p.name === answer.article) {
                    return p.id;
                }
                return null;
            });
            const token = await core_1.CliUx.ux.prompt('To revalidate articles, please enter the password: ');
            if (page) {
                try {
                    core_1.CliUx.ux.action.start('revalidating...');
                    const { data: { revalidated } } = await axios.get('http://heelog.dev/api/revalidate', {
                        data: {
                            type: 'single',
                            id: page.id,
                            token: token,
                        },
                    });
                    if (revalidated) {
                        core_1.CliUx.ux.action.stop('✅ done');
                    }
                    else {
                        core_1.CliUx.ux.action.stop('❌ failed');
                    }
                }
                catch {
                    this.error('❌ Please provide valid token to run revalidation');
                }
            }
        }
    }
}
exports.default = ArticlesRevalidate;
ArticlesRevalidate.description = 'Revalidate CDN cache on-demand for heelog articles';
ArticlesRevalidate.examples = ['<%= config.bin %> <%= command.id %> "--all"', '<%= config.bin %> <%= command.id %> "--single"'];
ArticlesRevalidate.flags = {
    all: core_1.Flags.boolean({ char: 'a', description: 'Revalidate All articles' }),
    single: core_1.Flags.boolean({ char: 's', description: 'Select a single article to revalidate' }),
};
ArticlesRevalidate.args = [];
